Copy the current schema to this directory at:
schema-latest.graphql

    For now we don't want this checked in

https://github.com/wandb/core/releases/tag/local%2Fv0.39.0
https://github.com/wandb/core/blob/bfc6ba2443548f3ec9ef0115503003b5e61e318d/services/gorilla/schema.graphql
